This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]

PATCH: more library renaming


I'm committing this patch, which finishes the library renaming in the
Java compiler.

1999-02-10  Tom Tromey  <tromey@cygnus.com>

	* jvspec.c (lang_specific_driver): Use libgcj, not libjava.
	* Makefile.in (jcf-path.o): Define LIBGCJ_ZIP_FILE.
	(libgcj_zip): Renamed.
	* jcf-path.c (add_entry): Use LIBGCJ_ZIP_FILE, not
	LIBJAVA_ZIP_FILE.
	(jcf_path_init): Use LIBGCJ_ZIP_FILE.

Tom

Index: Makefile.in
===================================================================
RCS file: /cvs/egcs/egcs/gcc/java/Makefile.in,v
retrieving revision 1.27
diff -u -r1.27 Makefile.in
--- Makefile.in	1999/02/01 12:38:56	1.27
+++ Makefile.in	1999/02/10 22:23:02
@@ -99,10 +99,10 @@
 srcdir = @srcdir@
 VPATH = @srcdir@
 
-# Directory holding libjava.zip.
+# Directory holding libgcj.zip.
 prefix = @prefix@
 datadir = @datadir@
-libjava_zip = $(datadir)/libjava.zip
+libgcj_zip = $(datadir)/libgcj.zip
 
 # Additional system libraries to link with.
 CLIB=
@@ -252,7 +252,7 @@
 
 jcf-path.o : jcf-path.c $(CONFIG_H) $(srcdir)/../system.h jcf.h
 	$(CC) -c $(ALL_CFLAGS) $(ALL_CPPFLAGS) $(INCLUDES) \
-	  -DLIBJAVA_ZIP_FILE='"$(libjava_zip)"' $(srcdir)/jcf-path.c
+	  -DLIBGCJ_ZIP_FILE='"$(libgcj_zip)"' $(srcdir)/jcf-path.c
 
 # These exist for maintenance purposes.
 
Index: jcf-path.c
===================================================================
RCS file: /cvs/egcs/egcs/gcc/java/jcf-path.c,v
retrieving revision 1.6
diff -u -r1.6 jcf-path.c
--- jcf-path.c	1998/12/16 21:20:44	1.6
+++ jcf-path.c	1999/02/10 22:23:08
@@ -1,6 +1,6 @@
 /* Handle CLASSPATH, -classpath, and path searching.
 
-   Copyright (C) 1998  Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999  Free Software Foundation, Inc.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -60,7 +60,7 @@
 
 /* We support several different ways to set the class path.
 
-   built-in system directory (only libjava.zip)
+   built-in system directory (only libgcj.zip)
    CLASSPATH environment variable
    -CLASSPATH overrides CLASSPATH
    -classpath option - overrides CLASSPATH, -CLASSPATH, and built-in
@@ -146,10 +146,10 @@
     {
       n->flags |= FLAG_ZIP;
       /* If the user uses -classpath then he'll have to include
-	 libjava.zip in the value.  We check for this in a simplistic
+	 libgcj.zip in the value.  We check for this in a simplistic
 	 way.  Symlinks will fool this test.  This is only used for
 	 -MM and -MMD, so it probably isn't terribly important.  */
-      if (! strcmp (filename, LIBJAVA_ZIP_FILE))
+      if (! strcmp (filename, LIBGCJ_ZIP_FILE))
 	n->flags |= FLAG_SYSTEM;
     }
 
@@ -220,7 +220,7 @@
   char *cp;
 
   add_entry (&sys_dirs, ".", 0);
-  add_entry (&sys_dirs, LIBJAVA_ZIP_FILE, 1);
+  add_entry (&sys_dirs, LIBGCJ_ZIP_FILE, 1);
 
   GET_ENV_PATH_LIST (cp, "CLASSPATH");
   add_path (&classpath_env, cp, 0);
Index: jvspec.c
===================================================================
RCS file: /cvs/egcs/egcs/gcc/java/jvspec.c,v
retrieving revision 1.12
diff -u -r1.12 jvspec.c
--- jvspec.c	1999/02/10 14:05:22	1.12
+++ jvspec.c	1999/02/10 22:23:13
@@ -1,6 +1,6 @@
  /* Specific flags and argument handling of the front-end of the 
    GNU compiler for the Java(TM) language.
-   Copyright (C) 1996, 97-98, 1999 Free Software Foundation, Inc.
+   Copyright (C) 1996, 1997, 1998, 1999 Free Software Foundation, Inc.
 
 This file is part of GNU CC.
 
@@ -61,7 +61,7 @@
 #define MATH_LIBRARY "-lm"
 #endif
 
-extern GENERIC_PTR xmalloc PROTO((size_t));
+extern char *xmalloc PROTO((size_t));
 extern int do_spec		PROTO((char *));
 extern char *input_filename;
 extern size_t input_filename_length;
@@ -98,7 +98,7 @@
   int saw_verbose_flag = 0;
 
   /* This will be 0 if we encounter a situation where we should not
-     link in libjava.  */
+     link in libgcj.  */
   int library = 1;
 
 #if COMBINE_INPUTS
@@ -154,8 +154,8 @@
   /* Saw `-l' option for the thread library.  */
   char *saw_threadlib = 0;
 
-  /* Saw `-ljava' on command line.  */
-  int saw_libjava = 0;
+  /* Saw `-lgcj' on command line.  */
+  int saw_libgcj = 0;
 
   /* Saw -C or -o option, respectively. */
   int saw_C = 0;
@@ -238,8 +238,8 @@
 	      main_class_name = argv[i] + 7;
 	      added--;
 	    }
-	  else if (strcmp (argv[i], "-ljava") == 0)
-	    saw_libjava = 1;
+	  else if (strcmp (argv[i], "-lgcj") == 0)
+	    saw_libgcj = 1;
 	  else if (strcmp (argv[i], "-lc") == 0)
 	    args[i] |= WITHLIBC;
 #ifdef GC_NAME
@@ -262,7 +262,7 @@
 	      if (argc == 2)
 		{
 		  /* If they only gave us `-v', don't try to link
-		     in libjava.  */ 
+		     in libgcj.  */ 
 		  library = 0;
 		}
 	    }
@@ -438,7 +438,7 @@
 	  continue;
 	}
 
       /* Make sure -ljava is before the math library, since libjava
 	 itself uses those math routines.  */
       if (!saw_math && (args[i] & MATHLIB) && library)
 	{
@@ -446,21 +446,21 @@
 	  saw_math = argv[i];
 	}
 
       /* Likewise -ljava must come before -lc.  */
       if (!saw_libc && (args[i] & WITHLIBC) && library)
 	{
 	  --j;
 	  saw_libc = argv[i];
 	}
 
       /* And -ljava must come before -lgcjgc.  */
       if (!saw_gc && (args[i] & GCLIB) && library)
 	{
 	  --j;
 	  saw_gc = argv[i];
 	}
 
       /* And -ljava must come before thread library.  */
       if (!saw_threadlib && (args[i] & THREADLIB) && library)
 	{
 	  --j;
@@ -501,10 +501,10 @@
   if (saw_g + saw_O == 0)
     arglist[j++] = "-g1";
 
-  /* Add `-ljava' if we haven't already done so.  */
-  if (library && ! saw_libjava)
+  /* Add `-lgcj' if we haven't already done so.  */
+  if (library && ! saw_libgcj)
     {
-      arglist[j++] = "-ljava";
+      arglist[j++] = "-lgcj";
       added_libraries++;
     }
 
@@ -527,7 +527,7 @@
 #endif
 
   /* Thread library must come after GC library as well as after
-     -ljava.  */
+     -lgcj.  */
   if (saw_threadlib)
     arglist[j++] = saw_threadlib;
 #ifdef THREAD_NAME
@@ -438,7 +438,7 @@
 	}
 
-      /* Make sure -ljava is before the math library, since libjava
+      /* Make sure -lgcj is before the math library, since libgcj
 	 itself uses those math routines.  */
       if (!saw_math && (args[i] & MATHLIB) && library)
@@ -446,21 +446,21 @@
 	}
 
-      /* Likewise -ljava must come before -lc.  */
+      /* Likewise -lgcj must come before -lc.  */
       if (!saw_libc && (args[i] & WITHLIBC) && library)
 	{
@@ -446,21 +446,21 @@
 	}
 
-      /* And -ljava must come before -lgcjgc.  */
+      /* And -lgcj must come before -lgcjgc.  */
       if (!saw_gc && (args[i] & GCLIB) && library)
 	{
@@ -446,21 +446,21 @@
 	}
 
-      /* And -ljava must come before thread library.  */
+      /* And -lgcj must come before thread library.  */
       if (!saw_threadlib && (args[i] & THREADLIB) && library)
 	{


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]